@@ -4,16 +4,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.081 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.083 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.081 ;
-use IO::Uncompress::Adapter::Lzf  2.081 ;
+use IO::Uncompress::Base  2.083 ;
+use IO::Uncompress::Adapter::Lzf  2.083 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzfError);
 
-$VERSION = '2.081';
+$VERSION = '2.083';
 $UnLzfError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
@@ -425,10 +425,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeOut => 0|1 >>
 
-When writing to a file or filehandle, set C<binmode> before writing to the
-file.
-
-Defaults to 0.
+This option is now a no-op. All files will be written  in binmode.
 
 =item C<< Append => 0|1 >>
 
